@@ -23,4 +23,5 @@ def test_mako_error_handling():
                        log_cm.output[0])
     test_case.assertIn('File ', log_cm.output[-1])
     test_case.assertIn('line ', log_cm.output[-1])
-    test_case.assertIn("in render_body: '% for suite in test_suites:'", log_cm.output[-1])
+    test_case.assertIn("in render_body: '% for suite_idx, suite in enumerate(test_suites, start=1):'",
+                       log_cm.output[-1])
